@@ -1,3 +1,9 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 #![warn(deprecated_in_future)]
 #![warn(future_incompatible)]
 #![warn(nonstandard_style)]
@@ -27,10 +33,10 @@ use std::io::{self, stdin, ErrorKind, IsTerminal, Read, Write};
 use std::path::{Component, PathBuf};
 use std::process::exit;
 
-use ansiterm::{ANSIStrings, Style};
+use nu_ansi_term::{AnsiStrings as ANSIStrings, Style};
 
 use crate::fs::feature::git::GitCache;
-use crate::fs::filter::GitIgnore;
+use crate::fs::filter::{FileFilterFlags::OnlyFiles, GitIgnore};
 use crate::fs::{Dir, File};
 use crate::options::stdin::FilesInput;
 use crate::options::{vars, Options, OptionsResult, Vars};
@@ -53,11 +59,6 @@ fn main() {
 
     logger::configure(env::var_os(vars::EZA_DEBUG).or_else(|| env::var_os(vars::EXA_DEBUG)));
 
-    #[cfg(windows)]
-    if let Err(e) = ansiterm::enable_ansi_support() {
-        warn!("Failed to enable ANSI support: {}", e);
-    }
-
     let stdout_istty = io::stdout().is_terminal();
 
     let mut input = String::new();
@@ -105,7 +106,7 @@ fn main() {
             info!("matching on exa.run");
             match exa.run() {
                 Ok(exit_status) => {
-                    trace!("exa.run: exit Ok(exit_status)");
+                    trace!("exa.run: exit Ok({exit_status})");
                     exit(exit_status);
                 }
 
@@ -247,7 +248,7 @@ fn git_repos(options: &Options, args: &[&OsStr]) -> bool {
     }
 }
 
-impl<'args> Exa<'args> {
+impl Exa<'_> {
     /// # Errors
     ///
     /// Will return `Err` if printing to stderr fails.
@@ -259,33 +260,28 @@ impl<'args> Exa<'args> {
         let mut exit_status = 0;
 
         for file_path in &self.input_paths {
-            match File::from_args(
+            let f = File::from_args(
                 PathBuf::from(file_path),
                 None,
                 None,
                 self.options.view.deref_links,
                 self.options.view.total_size,
-            ) {
-                Err(e) => {
-                    exit_status = 2;
-                    writeln!(io::stderr(), "{file_path:?}: {e}")?;
-                }
+                None,
+            );
 
-                Ok(f) => {
-                    if f.points_to_directory() && !self.options.dir_action.treat_dirs_as_files() {
-                        trace!("matching on to_dir");
-                        match f.to_dir() {
-                            Ok(d) => dirs.push(d),
-                            Err(e) if e.kind() == ErrorKind::PermissionDenied => {
-                                eprintln!("{file_path:?}: {e}");
-                                exit(exits::PERMISSION_DENIED);
-                            }
-                            Err(e) => writeln!(io::stderr(), "{file_path:?}: {e}")?,
-                        }
-                    } else {
-                        files.push(f);
-                    }
-                }
+            // We don't know whether this file exists, so we have to try to get
+            // the metadata to verify.
+            if let Err(e) = f.metadata() {
+                exit_status = 2;
+                writeln!(io::stderr(), "{file_path:?}: {e}")?;
+                continue;
+            }
+
+            if f.points_to_directory() && !self.options.dir_action.treat_dirs_as_files() {
+                trace!("matching on new Dir");
+                dirs.push(f.to_dir());
+            } else {
+                files.push(f);
             }
         }
 
@@ -313,7 +309,28 @@ impl<'args> Exa<'args> {
             file_style: file_name::Options { quote_style, .. },
             ..
         } = self.options.view;
-        for dir in dir_files {
+
+        let mut denied_dirs = vec![];
+
+        for mut dir in dir_files {
+            let dir = match dir.read() {
+                Ok(dir) => dir,
+                Err(e) => {
+                    if e.kind() == ErrorKind::PermissionDenied {
+                        eprintln!(
+                            "Permission denied: {} - code: {}",
+                            dir.path.display(),
+                            exits::PERMISSION_DENIED
+                        );
+                        denied_dirs.push(dir.path);
+                        continue;
+                    }
+
+                    eprintln!("{}: {}", dir.path.display(), e);
+                    continue;
+                }
+            };
+
             // Put a gap between directories, or between the list of files and
             // the first directory.
             if first {
@@ -343,13 +360,12 @@ impl<'args> Exa<'args> {
                 self.options.view.deref_links,
                 self.options.view.total_size,
             ) {
-                match file {
-                    Ok(file) => children.push(file),
-                    Err((path, e)) => writeln!(io::stderr(), "[{}: {}]", path.display(), e)?,
-                }
+                children.push(file);
             }
-
-            self.options.filter.filter_child_files(&mut children);
+            let recursing = self.options.dir_action.recurse_options().is_some();
+            self.options
+                .filter
+                .filter_child_files(recursing, &mut children);
             self.options.filter.sort_files(&mut children);
 
             if let Some(recurse_opts) = self.options.dir_action.recurse_options() {
@@ -359,21 +375,21 @@ impl<'args> Exa<'args> {
                     .filter(|&c| c != Component::CurDir)
                     .count()
                     + 1;
+                let follow_links = self.options.view.follow_links;
                 if !recurse_opts.tree && !recurse_opts.is_too_deep(depth) {
-                    let mut child_dirs = Vec::new();
-                    for child_dir in children
+                    let child_dirs = children
                         .iter()
-                        .filter(|f| f.is_directory() && !f.is_all_all)
-                    {
-                        match child_dir.to_dir() {
-                            Ok(d) => child_dirs.push(d),
-                            Err(e) => {
-                                writeln!(io::stderr(), "{}: {}", child_dir.path.display(), e)?;
-                            }
-                        }
-                    }
+                        .filter(|f| {
+                            (if follow_links {
+                                f.points_to_directory()
+                            } else {
+                                f.is_directory()
+                            }) && !f.is_all_all
+                        })
+                        .map(fs::File::to_dir)
+                        .collect::<Vec<Dir>>();
 
-                    self.print_files(Some(&dir), children)?;
+                    self.print_files(Some(dir), children)?;
                     match self.print_dirs(child_dirs, false, false, exit_status) {
                         Ok(_) => (),
                         Err(e) => return Err(e),
@@ -382,18 +398,35 @@ impl<'args> Exa<'args> {
                 }
             }
 
-            self.print_files(Some(&dir), children)?;
+            self.print_files(Some(dir), children)?;
+        }
+
+        if !denied_dirs.is_empty() {
+            eprintln!(
+                "\nSkipped {} directories due to permission denied: ",
+                denied_dirs.len()
+            );
+            for path in denied_dirs {
+                eprintln!("  {}", path.display());
+            }
         }
 
         Ok(exit_status)
     }
 
     /// Prints the list of files using whichever view is selected.
-    fn print_files(&mut self, dir: Option<&Dir>, files: Vec<File<'_>>) -> io::Result<()> {
+    fn print_files(&mut self, dir: Option<&Dir>, mut files: Vec<File<'_>>) -> io::Result<()> {
         if files.is_empty() {
             return Ok(());
         }
-
+        let recursing = self.options.dir_action.recurse_options().is_some();
+        let only_files = self.options.filter.flags.contains(&OnlyFiles);
+        if recursing && only_files {
+            files = files
+                .into_iter()
+                .filter(|f| !f.is_directory())
+                .collect::<Vec<_>>();
+        }
         let theme = &self.theme;
         let View {
             ref mode,
@@ -415,7 +448,20 @@ impl<'args> Exa<'args> {
                 r.render(&mut self.writer)
             }
 
-            (Mode::Grid(_), None) | (Mode::Lines, _) => {
+            (Mode::Grid(ref opts), None) => {
+                let filter = &self.options.filter;
+                let r = grid::Render {
+                    files,
+                    theme,
+                    file_style,
+                    opts,
+                    console_width: 80,
+                    filter,
+                };
+                r.render(&mut self.writer)
+            }
+
+            (Mode::Lines, _) => {
                 let filter = &self.options.filter;
                 let r = lines::Render {
                     files,
@@ -449,7 +495,6 @@ impl<'args> Exa<'args> {
             }
 
             (Mode::GridDetails(ref opts), Some(console_width)) => {
-                let grid = &opts.grid;
                 let details = &opts.details;
                 let row_threshold = opts.row_threshold;
 
@@ -463,7 +508,6 @@ impl<'args> Exa<'args> {
                     files,
                     theme,
                     file_style,
-                    grid,
                     details,
                     filter,
                     row_threshold,
