@@ -22,7 +22,7 @@ impl Icons {
     const CAD: char             = '\u{f0eeb}'; // 󰻫
     const CLOCK: char           = '\u{f43a}';  // 
     const COMPRESSED: char      = '\u{f410}';  // 
-    const CONFIG: char          = '\u{e615}';  // 
+    const CONFIG: char          = '\u{f107b}'; // 󱁻
     const CSS3: char            = '\u{e749}';  // 
     const DATABASE: char        = '\u{f1c0}';  // 
     const DIFF: char            = '\u{f440}';  // 
@@ -36,8 +36,8 @@ impl Icons {
     const ESLINT: char          = '\u{e655}';  // 
     const FILE: char            = '\u{f15b}';  // 
     const FILE_3D: char         = '\u{f01a7}'; // 󰆧
-    const FILE_OUTLINE: char    = '\u{f016}';  // 
     const FOLDER: char          = '\u{e5ff}';  // 
+    const FOLDER_BUILD: char    = '\u{f19fc}'; // 󱧼
     const FOLDER_CONFIG: char   = '\u{e5fc}';  // 
     const FOLDER_EXERCISM: char = '\u{ebe5}';  // 
     const FOLDER_GIT: char      = '\u{e5fb}';  // 
@@ -47,11 +47,12 @@ impl Icons {
     const FOLDER_NPM: char      = '\u{e5fa}';  // 
     const FOLDER_OCAML: char    = '\u{e67a}';  // 
     const FOLDER_OPEN: char     = '\u{f115}';  // 
+    const FILE_UNKNOW: char     = '\u{f086f}'; // 󰡯
     const FONT: char            = '\u{f031}';  // 
     const FREECAD: char         = '\u{f336}';  // 
     const GIMP: char            = '\u{f338}';  // 
     const GIST_SECRET: char     = '\u{eafa}';  // 
-    const GIT: char             = '\u{f1d3}';  // 
+    const GIT: char             = '\u{f02a2}'; // 󰊢
     const GODOT: char           = '\u{e65f}';  // 
     const GRADLE: char          = '\u{e660}';  // 
     const GRAPH: char           = '\u{f1049}'; // 󱁉
@@ -95,7 +96,7 @@ impl Icons {
     const LANG_PHP: char        = '\u{e73d}';  // 
     const LANG_PYTHON: char     = '\u{e606}';  // 
     const LANG_R: char          = '\u{e68a}';  // 
-    const LANG_RUBY: char       = '\u{e21e}';  // 
+    const LANG_RUBY: char       = '\u{e739}';  // 
     const LANG_RUBYRAILS: char  = '\u{e73b}';  // 
     const LANG_RUST: char       = '\u{e68b}';  // 
     const LANG_SASS: char       = '\u{e603}';  // 
@@ -111,7 +112,9 @@ impl Icons {
     const MAKE: char            = '\u{e673}';  // 
     const MARKDOWN: char        = '\u{f48a}';  // 
     const MUSTACHE: char        = '\u{e60f}';  // 
+    const NEWS: char            = '\u{f1ea}';  // 
     const NODEJS: char          = '\u{e718}';  // 
+    const NOTEBOOK: char          = '\u{e678}';  // 
     const NPM: char             = '\u{e71e}';  // 
     const OS_ANDROID: char      = '\u{e70e}';  // 
     const OS_APPLE: char        = '\u{f179}';  // 
@@ -137,8 +140,10 @@ impl Icons {
     const SQLITE: char          = '\u{e7c4}';  // 
     const SUBLIME: char         = '\u{e7aa}';  // 
     const SUBTITLE: char        = '\u{f0a16}'; // 󰨖
+    const TCL: char             = '\u{f06d3}'; // 󰛓
     const TERRAFORM: char       = '\u{f1062}'; // 󱁢
     const TEXT: char            = '\u{f15c}';  // 
+    const TODO: char            = '\u{f0ae}';  // 
     const TYPST: char           = '\u{f37f}';  // 
     const TMUX: char            = '\u{ebc8}';  // 
     const TOML: char            = '\u{e6b2}';  // 
@@ -149,6 +154,7 @@ impl Icons {
     const VIM: char             = '\u{e7c5}';  // 
     const WRENCH: char          = '\u{f0ad}';  // 
     const XML: char             = '\u{f05c0}'; // 󰗀
+    const XORG:char             = '\u{f369}';  // 
     const YAML: char            = '\u{e6a8}';  // 
     const YARN: char            = '\u{e6a7}';  // 
 }
@@ -164,6 +170,7 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     ".opam"               => Icons::FOLDER_OCAML,   // 
     ".ssh"                => Icons::FOLDER_KEY,     // 󰢬
     ".Trash"              => '\u{f1f8}',            // 
+    "build"               => Icons::FOLDER_BUILD,   // 󱧼
     "config"              => Icons::FOLDER_CONFIG,  // 
     "Contacts"            => '\u{f024c}',           // 󰉌
     "cron.d"              => Icons::FOLDER_CONFIG,  // 
@@ -173,6 +180,7 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     "cron.monthly"        => Icons::FOLDER_CONFIG,  // 
     "cron.weekly"         => Icons::FOLDER_CONFIG,  // 
     "Desktop"             => '\u{f108}',            // 
+    "Documents"           => '\u{f0c82}',           // 󰲂
     "Downloads"           => '\u{f024d}',           // 󰉍
     "etc"                 => Icons::FOLDER_CONFIG,  // 
     "Favorites"           => '\u{f069d}',           // 󰚝
@@ -184,14 +192,15 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     "Music"               => '\u{f1359}',           // 󱍙
     "node_modules"        => Icons::FOLDER_NPM,     // 
     "npm_cache"           => Icons::FOLDER_NPM,     // 
+    "pacman.d"            => Icons::FOLDER_CONFIG,  // 
     "pam.d"               => Icons::FOLDER_KEY,     // 󰢬
     "Pictures"            => '\u{f024f}',           // 󰉏
+    "src"                 => '\u{f08de}',           // 󰣞
     "ssh"                 => Icons::FOLDER_KEY,     // 󰢬
     "sudoers.d"           => Icons::FOLDER_KEY,     // 󰢬
     "Videos"              => '\u{f03d}',            // 
     "xbps.d"              => Icons::FOLDER_CONFIG,  // 
     "xorg.conf.d"         => Icons::FOLDER_CONFIG,  // 
-    "hi"                  => Icons::BINARY,         // 
     "cabal"               => Icons::LANG_HASKELL,   // 
 };
 
@@ -206,8 +215,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".bash_logout"        => Icons::SHELL,          // 󱆃
     ".bash_profile"       => Icons::SHELL,          // 󱆃
     ".CFUserTextEncoding" => Icons::OS_APPLE,       // 
-    ".clang-format"       => Icons::CONFIG,         // 
-    ".clang-tidy"         => Icons::CONFIG,         // 
+    ".clang-format"       => Icons::CONFIG,         // 󱁻
+    ".clang-tidy"         => Icons::CONFIG,         // 󱁻
     ".codespellrc"        => '\u{f04c6}',           // 󰓆
     ".condarc"            => '\u{e715}',            // 
     ".cshrc"              => Icons::SHELL,          // 󱆃
@@ -223,49 +232,56 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".eslintrc.yml"       => Icons::ESLINT,         // 
     ".gcloudignore"       => '\u{f11f6}',           // 󱇶
     ".fennelrc"           => Icons::LANG_FENNEL,    // 
-    ".gitattributes"      => Icons::GIT,            // 
-    ".git-blame-ignore-revs" => Icons::GIT,         // 
-    ".gitconfig"          => Icons::GIT,            // 
-    ".gitignore"          => Icons::GIT,            // 
-    ".gitignore_global"   => Icons::GIT,            // 
+    ".gitattributes"      => Icons::GIT,            // 󰊢
+    ".git-blame-ignore-revs" => Icons::GIT,         // 󰊢
+    ".gitconfig"          => Icons::GIT,            // 󰊢
+    ".gitignore"          => Icons::GIT,            // 󰊢
+    ".gitignore_global"   => Icons::GIT,            // 󰊢
     ".gitlab-ci.yml"      => '\u{f296}',            // 
-    ".gitmodules"         => Icons::GIT,            // 
+    ".gitmodules"         => Icons::GIT,            // 󰊢
     ".gtkrc-2.0"          => Icons::GTK,            // 
     ".gvimrc"             => Icons::VIM,            // 
-    ".htaccess"           => Icons::CONFIG,         // 
-    ".htpasswd"           => Icons::CONFIG,         // 
+    ".htaccess"           => Icons::CONFIG,         // 󱁻
+    ".htpasswd"           => Icons::CONFIG,         // 󱁻
     ".idea"               => Icons::INTELLIJ,       // 
     ".ideavimrc"          => Icons::VIM,            // 
-    ".inputrc"            => Icons::CONFIG,         // 
+    ".inputrc"            => Icons::CONFIG,         // 󱁻
     ".kshrc"              => Icons::SHELL,          // 󱆃
     ".login"              => Icons::SHELL,          // 󱆃
     ".logout"             => Icons::SHELL,          // 󱆃
-    ".luacheckrc"         => Icons::CONFIG,         // 
-    ".luaurc"             => Icons::CONFIG,         // 
+    ".luacheckrc"         => Icons::CONFIG,         // 󱁻
+    ".luaurc"             => Icons::CONFIG,         // 󱁻
     ".nanorc"             => '\u{e838}',            // 
     ".nuxtrc"             => '\u{f1106}',           // 󱄆
     ".ocamlinit"          => Icons::LANG_OCAML,     // 
-    ".mailmap"            => Icons::GIT,            // 
+    ".mailmap"            => Icons::GIT,            // 󰊢
     ".node_repl_history"  => Icons::NODEJS,         // 
     ".npmignore"          => Icons::NPM,            // 
     ".npmrc"              => Icons::NPM,            // 
     ".pre-commit-config.yaml" => '\u{f06e2}',       // 󰛢
     ".prettierignore"     => '\u{e6b4}',            // 
     ".prettierrc"         => '\u{e6b4}',            // 
+    ".prettierrc.json"    => '\u{e6b4}',            // 
+    ".prettierrc.json5"   => '\u{e6b4}',            // 
+    ".prettierrc.toml"    => '\u{e6b4}',            // 
+    ".prettierrc.yaml"    => '\u{e6b4}',            // 
+    ".prettierrc.yml"     => '\u{e6b4}',            // 
     ".parentlock"         => Icons::LOCK,           // 
     ".profile"            => Icons::SHELL,          // 󱆃
-    ".pylintrc"           => Icons::CONFIG,         // 
+    ".pylintrc"           => Icons::CONFIG,         // 󱁻
     ".python_history"     => Icons::LANG_PYTHON,    // 
     ".rustfmt.toml"       => Icons::LANG_RUST,      // 
-    ".rvm"                => Icons::LANG_RUBY,      // 
-    ".rvmrc"              => Icons::LANG_RUBY,      // 
+    ".rvm"                => Icons::LANG_RUBY,      // 
+    ".rvmrc"              => Icons::LANG_RUBY,      // 
     ".SRCINFO"            => '\u{f303}',            // 
+    ".stowrc"             => '\u{eef1}',            // 
     ".tcshrc"             => Icons::SHELL,          // 󱆃
     ".viminfo"            => Icons::VIM,            // 
     ".vimrc"              => Icons::VIM,            // 
-    ".Xauthority"         => Icons::CONFIG,         // 
-    ".xinitrc"            => Icons::CONFIG,         // 
-    ".Xresources"         => Icons::CONFIG,         // 
+    ".Xauthority"         => Icons::XORG,           // 
+    ".xinitrc"            => Icons::XORG,           // 
+    ".Xresources"         => Icons::XORG,           // 
+    ".xsession"           => Icons::XORG,           // 
     ".yarnrc"             => Icons::YARN,           // 
     ".zlogin"             => Icons::SHELL,          // 󱆃
     ".zlogout"            => Icons::SHELL,          // 󱆃
@@ -292,20 +308,25 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "Cargo.lock"          => Icons::LANG_RUST,      // 
     "Cargo.toml"          => Icons::LANG_RUST,      // 
     "CMakeLists.txt"      => '\u{e794}',            // 
+    "CHANGELOG"           => Icons::NEWS,           // 
+    "CHANGELOG.md"        => Icons::NEWS,           // 
+    "CHANGES"             => Icons::NEWS,           // 
+    "CHANGES.md"          => Icons::NEWS,           // 
     "CODE_OF_CONDUCT"     => '\u{f4ae}',            // 
     "CODE_OF_CONDUCT.md"  => '\u{f4ae}',            // 
     "composer.json"       => Icons::LANG_PHP,       // 
     "composer.lock"       => Icons::LANG_PHP,       // 
-    "config"              => Icons::CONFIG,         // 
-    "config.status"       => Icons::CONFIG,         // 
+    "config"              => Icons::CONFIG,         // 󱁻
+    "config.ru"           => Icons::LANG_RUBY,      // 
+    "config.status"       => Icons::CONFIG,         // 󱁻
     "configure"           => Icons::WRENCH,         // 
-    "configure.ac"        => Icons::CONFIG,         // 
-    "configure.in"        => Icons::CONFIG,         // 
+    "configure.ac"        => Icons::CONFIG,         // 󱁻
+    "configure.in"        => Icons::CONFIG,         // 󱁻
     "constraints.txt"     => Icons::LANG_PYTHON,    // 
     "COPYING"             => Icons::LICENSE,        // 
     "COPYRIGHT"           => Icons::LICENSE,        // 
-    "crontab"             => Icons::CONFIG,         // 
-    "crypttab"            => Icons::CONFIG,         // 
+    "crontab"             => Icons::CONFIG,         // 󱁻
+    "crypttab"            => Icons::CONFIG,         // 󱁻
     "csh.cshrc"           => Icons::SHELL,          // 󱆃
     "csh.login"           => Icons::SHELL,          // 󱆃
     "csh.logout"          => Icons::SHELL,          // 󱆃
@@ -314,11 +335,12 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "compose.yaml"        => Icons::DOCKER,         // 
     "compose.yml"         => Icons::DOCKER,         // 
     "docker-compose.yaml" => Icons::DOCKER,         // 
+    "dropbox"             => '\u{e707}',            // 
     "dune"                => Icons::LANG_OCAML,     // 
     "dune-project"        => Icons::WRENCH,         // 
     "Earthfile"           => '\u{f0ac}',            // 
     "COMMIT_EDITMSG"      => Icons::GIT,            // 
-    "environment"         => Icons::CONFIG,         // 
+    "environment"         => Icons::CONFIG,         // 󱁻
     "favicon.ico"         => '\u{e623}',            // 
     "flake.lock"          => '\u{f313}',            // 
     "fennelrc"            => Icons::LANG_FENNEL,    // 
@@ -326,6 +348,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "fp-info-cache"       => Icons::KICAD,          // 
     "fp-lib-table"        => Icons::KICAD,          // 
     "FreeCAD.conf"        => Icons::FREECAD,        // 
+    "Gemfile"             => Icons::LANG_RUBY,      // 
+    "Gemfile.lock"        => Icons::LANG_RUBY,      // 
     "GNUmakefile"         => Icons::MAKE,           // 
     "go.mod"              => Icons::LANG_GO,        // 
     "go.sum"              => Icons::LANG_GO,        // 
@@ -344,7 +368,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "gulpfile.js"         => Icons::GULP,           // 
     "gulpfile.ls"         => Icons::GULP,           // 
     "heroku.yml"          => '\u{e77b}',            // 
-    "hostname"            => Icons::CONFIG,         // 
+    "hostname"            => Icons::CONFIG,         // 󱁻
     "hypridle.conf"       => '\u{f359}',            // 
     "hyprland.conf"       => '\u{f359}',            // 
     "hyprlock.conf"       => '\u{f359}',            // 
@@ -357,8 +381,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "id_ed25519"          => Icons::PRIVATE_KEY,    // 󰌆
     "id_ed25519_sk"       => Icons::PRIVATE_KEY,    // 󰌆
     "id_rsa"              => Icons::PRIVATE_KEY,    // 󰌆
-    "index.theme"     => '\u{ee72}',           // 
-    "inputrc"             => Icons::CONFIG,         // 
+    "index.theme"         => '\u{ee72}',            // 
+    "inputrc"             => Icons::CONFIG,         // 󱁻
     "Jenkinsfile"         => '\u{e66e}',            // 
     "jsconfig.json"       => Icons::LANG_JAVASCRIPT,// 
     "Justfile"            => Icons::WRENCH,         // 
@@ -395,6 +419,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "MANIFEST.in"         => Icons::LANG_PYTHON,    // 
     "mix.lock"            => Icons::LANG_ELIXIR,    // 
     "mpv.conf"            => '\u{f36e}',            // 
+    "NEWS"                => Icons::NEWS,           // 
+    "NEWS.md"             => Icons::NEWS,           // 
     "npm-shrinkwrap.json" => Icons::NPM,            // 
     "npmrc"               => Icons::NPM,            // 
     "package-lock.json"   => Icons::NPM,            // 
@@ -413,7 +439,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "qt5ct.conf"          => Icons::QT,             // 
     "qt6ct.conf"          => Icons::QT,             // 
     "QtProject.conf"      => Icons::QT,             // 
-    "Rakefile"            => Icons::LANG_RUBY,      // 
+    "Rakefile"            => Icons::LANG_RUBY,      // 
     "README"              => Icons::README,         // 󰂺
     "README.md"           => Icons::README,         // 󰂺
     "release.toml"        => Icons::LANG_RUST,      // 
@@ -421,26 +447,30 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "requirements.txt"    => Icons::LANG_PYTHON,    // 
     "robots.txt"          => '\u{f06a9}',           // 󰚩
     "rubydoc"             => Icons::LANG_RUBYRAILS, // 
-    "rvmrc"               => Icons::LANG_RUBY,      // 
+    "rvmrc"               => Icons::LANG_RUBY,      // 
     "SECURITY"            => '\u{f0483}',           // 󰒃
     "SECURITY.md"         => '\u{f0483}',           // 󰒃
     "settings.gradle.kts" => Icons::GRADLE,         // 
     "shadow"              => Icons::LOCK,           // 
-    "shells"              => Icons::CONFIG,         // 
+    "shells"              => Icons::CONFIG,         // 󱁻
     "sudoers"             => Icons::LOCK,           // 
     "sxhkdrc"             => Icons::CONFIG,         // 
     "sym-lib-table"       => Icons::KICAD,          // 
     "timezone"            => Icons::CLOCK,          // 
     "tmux.conf"           => Icons::TMUX,           // 
     "tmux.conf.local"     => Icons::TMUX,           // 
+    "TODO"                => Icons::TODO,           // 
+    "TODO.md"             => Icons::TODO,           // 
     "tsconfig.json"       => Icons::LANG_TYPESCRIPT,// 
     "Vagrantfile"         => '\u{2371}',            // ⍱
     "vlcrc"               => '\u{f057c}',           // 󰕼
     "webpack.config.js"   => '\u{f072b}',           // 󰜫
+    "xorg.conf"           => Icons::XORG,           // 
+    "xsettingsd.conf"     => Icons::XORG,           // 
     "weston.ini"          => '\u{f367}',            // 
-    "xmobarrc"            => '\u{f35e}',            // 
-    "xmobarrc.hs"         => '\u{f35e}',            // 
-    "xmonad.hs"           => '\u{f35e}',            // 
+    "xmobarrc"            => Icons::XORG,           // 
+    "xmobarrc.hs"         => Icons::XORG,           // 
+    "xmonad.hs"           => Icons::XORG,           // 
     "yarn.lock"           => Icons::YARN,           // 
     "zlogin"              => Icons::SHELL,          // 󱆃
     "zlogout"             => Icons::SHELL,          // 󱆃
@@ -514,19 +544,20 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "cbz"            => Icons::IMAGE,            // 
     "cc"             => Icons::LANG_CPP,         // 
     "cert"           => Icons::GIST_SECRET,      // 
-    "cfg"            => Icons::CONFIG,           // 
+    "cfg"            => Icons::CONFIG,           // 󱁻
     "cjs"            => Icons::LANG_JAVASCRIPT,  // 
     "class"          => Icons::LANG_JAVA,        // 
     "clj"            => '\u{e768}',              // 
+    "cljc"           => '\u{e768}',              // 
     "cljs"           => '\u{e76a}',              // 
     "cls"            => Icons::LANG_TEX,         // 
     "cmake"          => '\u{e794}',              // 
     "cmd"            => Icons::OS_WINDOWS,       // 
     "coffee"         => '\u{f0f4}',              // 
-    "com"            => Icons::OS_WINDOWS_CMD,   // 
+    "com"            => '\u{e629}',              // 
     "conda"          => '\u{e715}',              // 
-    "conf"           => Icons::CONFIG,           // 
-    "config"         => Icons::CONFIG,           // 
+    "conf"           => Icons::CONFIG,           // 󱁻
+    "config"         => Icons::CONFIG,           // 󱁻
     "cow"            => '\u{f019a}',             // 󰆚
     "cp"             => Icons::LANG_CPP,         // 
     "cpio"           => Icons::COMPRESSED,       // 
@@ -574,6 +605,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "dylib"          => Icons::OS_APPLE,         // 
     "ebook"          => Icons::BOOK,             // 
     "ebuild"         => '\u{f30d}',              // 
+    "edn"            => '\u{e76a}',              // 
     "editorconfig"   => '\u{e652}',              // 
     "eex"            => Icons::LANG_ELIXIR,      // 
     "ejs"            => '\u{e618}',              // 
@@ -592,6 +624,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "exe"            => Icons::OS_WINDOWS_CMD,   // 
     "exs"            => Icons::LANG_ELIXIR,      // 
     "f"              => Icons::LANG_FORTRAN,     // 󱈚
+    "f#"             => Icons::LANG_FSHARP,      // 
     "f3d"            => Icons::CAD,              // 󰻫
     "f3z"            => Icons::CAD,              // 󰻫
     "f90"            => Icons::LANG_FORTRAN,     // 󱈚
@@ -623,6 +656,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "fs"             => Icons::LANG_FSHARP,      // 
     "fsi"            => Icons::LANG_FSHARP,      // 
     "fsproj"         => Icons::LANG_FSHARP,      // 
+    "fsscript"       => Icons::LANG_FSHARP,      // 
     "fsx"            => Icons::LANG_FSHARP,      // 
     "gba"            => '\u{f1393}',             // 󱎓
     "gbl"            => Icons::EDA_PCB,          // 
@@ -633,12 +667,12 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "gcode"          => '\u{f0af4}',             // 󰫴
     "gd"             => Icons::GODOT,            // 
     "gdoc"           => Icons::DOCUMENT,         // 
-    "gem"            => Icons::LANG_RUBY,        // 
-    "gemfile"        => Icons::LANG_RUBY,        // 
-    "gemspec"        => Icons::LANG_RUBY,        // 
+    "gem"            => Icons::LANG_RUBY,        // 
+    "gemfile"        => Icons::LANG_RUBY,        // 
+    "gemspec"        => Icons::LANG_RUBY,        // 
     "gform"          => '\u{f298}',              // 
     "gif"            => Icons::IMAGE,            // 
-    "git"            => Icons::GIT,              // 
+    "git"            => Icons::GIT,              // 󰊢
     "gleam"          => Icons::LANG_GLEAM,       // 󰦥
     "gm1"            => Icons::EDA_PCB,          // 
     "gml"            => Icons::EDA_PCB,          // 
@@ -656,7 +690,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "gto"            => Icons::EDA_PCB,          // 
     "gtp"            => Icons::EDA_PCB,          // 
     "gts"            => Icons::EDA_PCB,          // 
-    "guardfile"      => Icons::LANG_RUBY,        // 
+    "guardfile"      => Icons::LANG_RUBY,        // 
     "gv"             => Icons::GRAPH,            // 󱁉
     "gvy"            => Icons::LANG_GROOVY,      // 
     "gz"             => Icons::COMPRESSED,       // 
@@ -671,6 +705,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "heif"           => Icons::IMAGE,            // 
     "hex"            => '\u{f12a7}',             // 󱊧
     "hh"             => Icons::LANG_CPP,         // 
+    "hi"             => Icons::BINARY,           // 
     "hpp"            => Icons::LANG_CPP,         // 
     "hrl"            => '\u{e7b1}',              // 
     "hs"             => Icons::LANG_HASKELL,     // 
@@ -691,9 +726,9 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "img"            => Icons::DISK_IMAGE,       // 
     "iml"            => Icons::INTELLIJ,         // 
     "info"           => Icons::INFO,             // 
-    "ini"            => Icons::CONFIG,           // 
+    "ini"            => Icons::CONFIG,           // 󱁻
     "inl"            => Icons::LANG_C,           // 
-    "ipynb"          => '\u{e80f}',              // 
+    "ipynb"          => Icons::NOTEBOOK,              // 
     "ino"            => Icons::LANG_ARDUINO,     // 
     "ipt"            => Icons::CAD,              // 󰻫
     "iso"            => Icons::DISK_IMAGE,       // 
@@ -778,6 +813,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "md"             => Icons::MARKDOWN,         // 
     "md5"            => Icons::SHIELD_CHECK,     // 󰕥
     "mdb"            => Icons::DATABASE,         // 
+    "mdx"            => Icons::MARKDOWN,         // 
     "mid"            => '\u{f08f2}',             // 󰣲
     "mjs"            => Icons::LANG_JAVASCRIPT,  // 
     "mk"             => Icons::MAKE,             // 
@@ -823,6 +859,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ogg"            => Icons::AUDIO,            // 
     "ogm"            => Icons::VIDEO,            // 
     "ogv"            => Icons::VIDEO,            // 
+    "opam"           => '\u{f0627}',             // 󰘧
     "opml"           => Icons::XML,              // 󰗀
     "opus"           => Icons::AUDIO,            // 
     "orf"            => Icons::IMAGE,            // 
@@ -861,6 +898,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ppt"            => Icons::SLIDE,            // 
     "pptx"           => Icons::SLIDE,            // 
     "prjpcb"         => Icons::EDA_PCB,          // 
+    "procfile"       => Icons::LANG_RUBY,        // 
     "properties"     => Icons::JSON,             // 
     "prql"           => Icons::DATABASE,         // 
     "ps"             => Icons::VECTOR,           // 󰕙
@@ -873,6 +911,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "psm1"           => Icons::POWERSHELL,       // 
     "pub"            => Icons::PUBLIC_KEY,       // 󰷖
     "purs"           => '\u{e630}',              // 
+    "pxd"            => Icons::LANG_PYTHON,      // 
     "pxm"            => Icons::IMAGE,            // 
     "py"             => Icons::LANG_PYTHON,      // 
     "pyc"            => Icons::LANG_PYTHON,      // 
@@ -880,6 +919,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "pyi"            => Icons::LANG_PYTHON,      // 
     "pyo"            => Icons::LANG_PYTHON,      // 
     "pyw"            => Icons::LANG_PYTHON,      // 
+    "pyx"            => Icons::LANG_PYTHON,      // 
     "qcow"           => Icons::DISK_IMAGE,       // 
     "qcow2"          => Icons::DISK_IMAGE,       // 
     "qm"             => Icons::TRANSLATION,      // 󰗊
@@ -887,10 +927,12 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "qrc"            => Icons::QT,               // 
     "qss"            => Icons::QT,               // 
     "r"              => Icons::LANG_R,           // 
+    "rake"           => Icons::LANG_RUBY,        // 
+    "rakefile"       => Icons::LANG_RUBY,        // 
     "rar"            => Icons::COMPRESSED,       // 
     "raw"            => Icons::IMAGE,            // 
     "razor"          => Icons::RAZOR,            // 
-    "rb"             => Icons::LANG_RUBY,        // 
+    "rb"             => Icons::LANG_RUBY,        // 
     "rdata"          => Icons::LANG_R,           // 
     "rdb"            => '\u{e76d}',              // 
     "rdoc"           => Icons::MARKDOWN,         // 
@@ -902,13 +944,13 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "rmeta"          => Icons::LANG_RUST,        // 
     "rpm"            => '\u{e7bb}',              // 
     "rs"             => Icons::LANG_RUST,        // 
-    "rspec"          => Icons::LANG_RUBY,        // 
-    "rspec_parallel" => Icons::LANG_RUBY,        // 
-    "rspec_status"   => Icons::LANG_RUBY,        // 
+    "rspec"          => Icons::LANG_RUBY,        // 
+    "rspec_parallel" => Icons::LANG_RUBY,        // 
+    "rspec_status"   => Icons::LANG_RUBY,        // 
     "rss"            => '\u{f09e}',              // 
     "rst"            => Icons::TEXT,             // 
     "rtf"            => Icons::TEXT,             // 
-    "ru"             => Icons::LANG_RUBY,        // 
+    "ru"             => Icons::LANG_RUBY,        // 
     "rubydoc"        => Icons::LANG_RUBYRAILS,   // 
     "s"              => Icons::LANG_ASSEMBLY,    // 
     "s3db"           => Icons::SQLITE,           // 
@@ -968,6 +1010,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "sublime-settings"=>Icons::SUBLIME,          // 
     "sublime-snippet"=> Icons::SUBLIME,          // 
     "sublime-theme"  => Icons::SUBLIME,          // 
+    "suo"            => '\u{e70c}',              // 
     "svelte"         => '\u{e697}',              // 
     "sv"             => Icons::LANG_HDL,         // 󰍛
     "svg"            => Icons::VECTOR,           // 󰕙
@@ -975,14 +1018,13 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "swf"            => Icons::AUDIO,            // 
     "swift"          => '\u{e755}',              // 
     "t"              => Icons::LANG_PERL,        // 
-    "tape"           => '\u{F0A1B}',             // 󰨛
+    "tbc"            => Icons::TCL,              // 󰛓
     "tar"            => Icons::COMPRESSED,       // 
     "taz"            => Icons::COMPRESSED,       // 
-    "tbc"            => '\u{f06d3}',             // 󰛓
     "tbz"            => Icons::COMPRESSED,       // 
     "tbz2"           => Icons::COMPRESSED,       // 
     "tc"             => Icons::DISK_IMAGE,       // 
-    "tcl"            => '\u{f06d3}',             // 󰛓
+    "tcl"            => Icons::TCL,              // 󰛓
     "tex"            => Icons::LANG_TEX,         // 
     "tf"             => Icons::TERRAFORM,        // 󱁢
     "tfstate"        => Icons::TERRAFORM,        // 󱁢
@@ -1041,6 +1083,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "xaml"           => '\u{f0673}',             // 󰙳
     "xcf"            => Icons::GIMP,             // 
     "xci"            => '\u{F07E1}',             // 󰟡
+    "xcplayground"   => '\u{e755}',              // 
     "xhtml"          => Icons::HTML5,            // 
     "xlr"            => Icons::SHEET,            // 
     "xls"            => Icons::SHEET,            // 
@@ -1096,6 +1139,6 @@ pub fn icon_for_file(file: &File<'_>) -> char {
     } else if let Some(ext) = file.ext.as_ref() {
         *EXTENSION_ICONS.get(ext.as_str()).unwrap_or(&Icons::FILE) // 
     } else {
-        Icons::FILE_OUTLINE // 
+        Icons::FILE_UNKNOW // 󰡯
     }
 }
